<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: timezones.php 5670 2006-09-06 14:53:01Z yeupou $
#
#  Copyright 2006 (c) Mathieu Roy <yeupou--gnu.org>
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

# Valid timezones for PHP from php.net, except the ones of the category
# others that seems to be duplicates for theses ones. We can expect people
# to know in which country/city they are. Knowning if they are at GMT+3 or 
# GMT+4 may be more picky, so since there are differents ways to tell the
# timezone, we will take the easy one.

$TZs[]='Africa/Abidjan';
$TZs[]='Africa/Accra';
$TZs[]='Africa/Addis_Ababa';
$TZs[]='Africa/Algiers';
$TZs[]='Africa/Asmera';
$TZs[]='Africa/Bamako';
$TZs[]='Africa/Bangui';
$TZs[]='Africa/Banjul';
$TZs[]='Africa/Bissau';
$TZs[]='Africa/Blantyre';
$TZs[]='Africa/Brazzaville';
$TZs[]='Africa/Bujumbura';
$TZs[]='Africa/Cairo';
$TZs[]='Africa/Casablanca';
$TZs[]='Africa/Ceuta';
$TZs[]='Africa/Conakry';
$TZs[]='Africa/Dakar';
$TZs[]='Africa/Dar_es_Salaam';
$TZs[]='Africa/Djibouti';
$TZs[]='Africa/Douala';
$TZs[]='Africa/El_Aaiun';
$TZs[]='Africa/Freetown';
$TZs[]='Africa/Gaborone';
$TZs[]='Africa/Harare';
$TZs[]='Africa/Johannesburg';
$TZs[]='Africa/Kampala';
$TZs[]='Africa/Khartoum';
$TZs[]='Africa/Kigali';
$TZs[]='Africa/Kinshasa';
$TZs[]='Africa/Lagos';
$TZs[]='Africa/Libreville';
$TZs[]='Africa/Lome';
$TZs[]='Africa/Luanda';
$TZs[]='Africa/Lubumbashi';
$TZs[]='Africa/Lusaka';
$TZs[]='Africa/Malabo';
$TZs[]='Africa/Maputo';
$TZs[]='Africa/Maseru';
$TZs[]='Africa/Mbabane';
$TZs[]='Africa/Mogadishu';
$TZs[]='Africa/Monrovia';
$TZs[]='Africa/Nairobi';
$TZs[]='Africa/Ndjamena';
$TZs[]='Africa/Niamey';
$TZs[]='Africa/Nouakchott';
$TZs[]='Africa/Ouagadougou';
$TZs[]='Africa/Porto-Novo';
$TZs[]='Africa/Sao_Tome';
$TZs[]='Africa/Timbuktu';
$TZs[]='Africa/Tripoli';
$TZs[]='Africa/Tunis';
$TZs[]='Africa/Windhoek';
$TZs[]='America/Adak';
$TZs[]='America/Anchorage';
$TZs[]='America/Anguilla';
$TZs[]='America/Antigua';
$TZs[]='America/Araguaina';
$TZs[]='America/Argentina/Buenos_Aires';
$TZs[]='America/Argentina/Catamarca';
$TZs[]='America/Argentina/ComodRivadavia';
$TZs[]='America/Argentina/Cordoba';
$TZs[]='America/Argentina/Jujuy';
$TZs[]='America/Argentina/La_Rioja';
$TZs[]='America/Argentina/Mendoza';
$TZs[]='America/Argentina/Rio_Gallegos';
$TZs[]='America/Argentina/San_Juan';
$TZs[]='America/Argentina/Tucuman';
$TZs[]='America/Argentina/Ushuaia';
$TZs[]='America/Aruba';
$TZs[]='America/Asuncion';
$TZs[]='America/Atka';
$TZs[]='America/Bahia';
$TZs[]='America/Barbados';
$TZs[]='America/Belem';
$TZs[]='America/Belize';
$TZs[]='America/Boa_Vista';
$TZs[]='America/Bogota';
$TZs[]='America/Boise';
$TZs[]='America/Buenos_Aires';
$TZs[]='America/Cambridge_Bay';
$TZs[]='America/Campo_Grande';
$TZs[]='America/Cancun';
$TZs[]='America/Caracas';
$TZs[]='America/Catamarca';
$TZs[]='America/Cayenne';
$TZs[]='America/Cayman';
$TZs[]='America/Chicago';
$TZs[]='America/Chihuahua';
$TZs[]='America/Coral_Harbour';
$TZs[]='America/Cordoba';
$TZs[]='America/Costa_Rica';
$TZs[]='America/Cuiaba';
$TZs[]='America/Curacao';
$TZs[]='America/Danmarkshavn';
$TZs[]='America/Dawson';
$TZs[]='America/Dawson_Creek';
$TZs[]='America/Denver';
$TZs[]='America/Detroit';
$TZs[]='America/Dominica';
$TZs[]='America/Edmonton';
$TZs[]='America/Eirunepe';
$TZs[]='America/El_Salvador';
$TZs[]='America/Ensenada';
$TZs[]='America/Fort_Wayne';
$TZs[]='America/Fortaleza';
$TZs[]='America/Glace_Bay';
$TZs[]='America/Godthab';
$TZs[]='America/Goose_Bay';
$TZs[]='America/Grand_Turk';
$TZs[]='America/Grenada';
$TZs[]='America/Guadeloupe';
$TZs[]='America/Guatemala';
$TZs[]='America/Guayaquil';
$TZs[]='America/Guyana';
$TZs[]='America/Halifax';
$TZs[]='America/Havana';
$TZs[]='America/Hermosillo';
$TZs[]='America/Indiana/Indianapolis';
$TZs[]='America/Indiana/Knox';
$TZs[]='America/Indiana/Marengo';
$TZs[]='America/Indiana/Vevay';
$TZs[]='America/Indianapolis';
$TZs[]='America/Inuvik';
$TZs[]='America/Iqaluit';
$TZs[]='America/Jamaica';
$TZs[]='America/Jujuy';
$TZs[]='America/Juneau';
$TZs[]='America/Kentucky/Louisville';
$TZs[]='America/Kentucky/Monticello';
$TZs[]='America/Knox_IN';
$TZs[]='America/La_Paz';
$TZs[]='America/Lima';
$TZs[]='America/Los_Angeles';
$TZs[]='America/Louisville';
$TZs[]='America/Maceio';
$TZs[]='America/Managua';
$TZs[]='America/Manaus';
$TZs[]='America/Martinique';
$TZs[]='America/Mazatlan';
$TZs[]='America/Mendoza';
$TZs[]='America/Menominee';
$TZs[]='America/Merida';
$TZs[]='America/Mexico_City';
$TZs[]='America/Miquelon';
$TZs[]='America/Monterrey';
$TZs[]='America/Montevideo';
$TZs[]='America/Montreal';
$TZs[]='America/Montserrat';
$TZs[]='America/Nassau';
$TZs[]='America/New_York';
$TZs[]='America/Nipigon';
$TZs[]='America/Nome';
$TZs[]='America/Noronha';
$TZs[]='America/North_Dakota/Center';
$TZs[]='America/Panama';
$TZs[]='America/Pangnirtung';
$TZs[]='America/Paramaribo';
$TZs[]='America/Phoenix';
$TZs[]='America/Port-au-Prince';
$TZs[]='America/Port_of_Spain';
$TZs[]='America/Porto_Acre';
$TZs[]='America/Porto_Velho';
$TZs[]='America/Puerto_Rico';
$TZs[]='America/Rainy_River';
$TZs[]='America/Rankin_Inlet';
$TZs[]='America/Recife';
$TZs[]='America/Regina';
$TZs[]='America/Rio_Branco';
$TZs[]='America/Rosario';
$TZs[]='America/Santiago';
$TZs[]='America/Santo_Domingo';
$TZs[]='America/Sao_Paulo';
$TZs[]='America/Scoresbysund';
$TZs[]='America/Shiprock';
$TZs[]='America/St_Johns';
$TZs[]='America/St_Kitts';
$TZs[]='America/St_Lucia';
$TZs[]='America/St_Thomas';
$TZs[]='America/St_Vincent';
$TZs[]='America/Swift_Current';
$TZs[]='America/Tegucigalpa';
$TZs[]='America/Thule';
$TZs[]='America/Thunder_Bay';
$TZs[]='America/Tijuana';
$TZs[]='America/Toronto';
$TZs[]='America/Tortola';
$TZs[]='America/Vancouver';
$TZs[]='America/Virgin';
$TZs[]='America/Whitehorse';
$TZs[]='America/Winnipeg';
$TZs[]='America/Yakutat';
$TZs[]='America/Yellowknife';
$TZs[]='Antarctica/Casey';
$TZs[]='Antarctica/Davis';
$TZs[]='Antarctica/DumontDUrville';
$TZs[]='Antarctica/Mawson';
$TZs[]='Antarctica/McMurdo';
$TZs[]='Antarctica/Palmer';
$TZs[]='Antarctica/Rothera';
$TZs[]='Antarctica/South_Pole';
$TZs[]='Antarctica/Syowa';
$TZs[]='Antarctica/Vostok';
$TZs[]='Arctic/Longyearbyen';
$TZs[]='Asia/Aden';
$TZs[]='Asia/Almaty';
$TZs[]='Asia/Amman';
$TZs[]='Asia/Anadyr';
$TZs[]='Asia/Aqtau';
$TZs[]='Asia/Aqtobe';
$TZs[]='Asia/Ashgabat';
$TZs[]='Asia/Ashkhabad';
$TZs[]='Asia/Baghdad';
$TZs[]='Asia/Bahrain';
$TZs[]='Asia/Baku';
$TZs[]='Asia/Bangkok';
$TZs[]='Asia/Beirut';
$TZs[]='Asia/Bishkek';
$TZs[]='Asia/Brunei';
$TZs[]='Asia/Calcutta';
$TZs[]='Asia/Choibalsan';
$TZs[]='Asia/Chongqing';
$TZs[]='Asia/Chungking';
$TZs[]='Asia/Colombo';
$TZs[]='Asia/Dacca';
$TZs[]='Asia/Damascus';
$TZs[]='Asia/Dhaka';
$TZs[]='Asia/Dili';
$TZs[]='Asia/Dubai';
$TZs[]='Asia/Dushanbe';
$TZs[]='Asia/Gaza';
$TZs[]='Asia/Harbin';
$TZs[]='Asia/Hong_Kong';
$TZs[]='Asia/Hovd';
$TZs[]='Asia/Irkutsk';
$TZs[]='Asia/Istanbul';
$TZs[]='Asia/Jakarta';
$TZs[]='Asia/Jayapura';
$TZs[]='Asia/Jerusalem';
$TZs[]='Asia/Kabul';
$TZs[]='Asia/Kamchatka';
$TZs[]='Asia/Karachi';
$TZs[]='Asia/Kashgar';
$TZs[]='Asia/Katmandu';
$TZs[]='Asia/Krasnoyarsk';
$TZs[]='Asia/Kuala_Lumpur';
$TZs[]='Asia/Kuching';
$TZs[]='Asia/Kuwait';
$TZs[]='Asia/Macao';
$TZs[]='Asia/Macau';
$TZs[]='Asia/Magadan';
$TZs[]='Asia/Makassar';
$TZs[]='Asia/Manila';
$TZs[]='Asia/Muscat';
$TZs[]='Asia/Nicosia';
$TZs[]='Asia/Novosibirsk';
$TZs[]='Asia/Omsk';
$TZs[]='Asia/Oral';
$TZs[]='Asia/Phnom_Penh';
$TZs[]='Asia/Pontianak';
$TZs[]='Asia/Pyongyang';
$TZs[]='Asia/Qatar';
$TZs[]='Asia/Qyzylorda';
$TZs[]='Asia/Rangoon';
$TZs[]='Asia/Riyadh';
$TZs[]='Asia/Saigon';
$TZs[]='Asia/Sakhalin';
$TZs[]='Asia/Samarkand';
$TZs[]='Asia/Seoul';
$TZs[]='Asia/Shanghai';
$TZs[]='Asia/Singapore';
$TZs[]='Asia/Taipei';
$TZs[]='Asia/Tashkent';
$TZs[]='Asia/Tbilisi';
$TZs[]='Asia/Tehran';
$TZs[]='Asia/Tel_Aviv';
$TZs[]='Asia/Thimbu';
$TZs[]='Asia/Thimphu';
$TZs[]='Asia/Tokyo';
$TZs[]='Asia/Ujung_Pandang';
$TZs[]='Asia/Ulaanbaatar';
$TZs[]='Asia/Ulan_Bator';
$TZs[]='Asia/Urumqi';
$TZs[]='Asia/Vientiane';
$TZs[]='Asia/Vladivostok';
$TZs[]='Asia/Yakutsk';
$TZs[]='Asia/Yekaterinburg';
$TZs[]='Asia/Yerevan';
$TZs[]='Atlantic/Azores';
$TZs[]='Atlantic/Bermuda';
$TZs[]='Atlantic/Canary';
$TZs[]='Atlantic/Cape_Verde';
$TZs[]='Atlantic/Faeroe';
$TZs[]='Atlantic/Jan_Mayen';
$TZs[]='Atlantic/Madeira';
$TZs[]='Atlantic/Reykjavik';
$TZs[]='Atlantic/South_Georgia';
$TZs[]='Atlantic/St_Helena';
$TZs[]='Atlantic/Stanley';
$TZs[]='Australia/ACT';
$TZs[]='Australia/Adelaide';
$TZs[]='Australia/Brisbane';
$TZs[]='Australia/Broken_Hill';
$TZs[]='Australia/Canberra';
$TZs[]='Australia/Currie';
$TZs[]='Australia/Darwin';
$TZs[]='Australia/Hobart';
$TZs[]='Australia/LHI';
$TZs[]='Australia/Lindeman';
$TZs[]='Australia/Lord_Howe';
$TZs[]='Australia/Melbourne';
$TZs[]='Australia/NSW';
$TZs[]='Australia/North';
$TZs[]='Australia/Perth';
$TZs[]='Australia/Queensland';
$TZs[]='Australia/South';
$TZs[]='Australia/Sydney';
$TZs[]='Australia/Tasmania';
$TZs[]='Australia/Victoria';
$TZs[]='Australia/West';
$TZs[]='Australia/Yancowinna';
$TZs[]='Brazil/Acre';
$TZs[]='Brazil/DeNoronha';
$TZs[]='Brazil/East';
$TZs[]='Brazil/West';
$TZs[]='Canada/Atlantic';
$TZs[]='Canada/Central';
$TZs[]='Canada/East-Saskatchewan';
$TZs[]='Canada/Eastern';
$TZs[]='Canada/Mountain';
$TZs[]='Canada/Newfoundland';
$TZs[]='Canada/Pacific';
$TZs[]='Canada/Saskatchewan';
$TZs[]='Canada/Yukon';
$TZs[]='Chile/Continental';
$TZs[]='Chile/EasterIsland';
$TZs[]='Europe/Amsterdam';
$TZs[]='Europe/Andorra';
$TZs[]='Europe/Athens';
$TZs[]='Europe/Belfast';
$TZs[]='Europe/Belgrade';
$TZs[]='Europe/Berlin';
$TZs[]='Europe/Bratislava';
$TZs[]='Europe/Brussels';
$TZs[]='Europe/Bucharest';
$TZs[]='Europe/Budapest';
$TZs[]='Europe/Chisinau';
$TZs[]='Europe/Copenhagen';
$TZs[]='Europe/Dublin';
$TZs[]='Europe/Gibraltar';
$TZs[]='Europe/Helsinki';
$TZs[]='Europe/Istanbul';
$TZs[]='Europe/Kaliningrad';
$TZs[]='Europe/Kiev';
$TZs[]='Europe/Lisbon';
$TZs[]='Europe/Ljubljana';
$TZs[]='Europe/London';
$TZs[]='Europe/Luxembourg';
$TZs[]='Europe/Madrid';
$TZs[]='Europe/Malta';
$TZs[]='Europe/Mariehamn';
$TZs[]='Europe/Minsk';
$TZs[]='Europe/Monaco';
$TZs[]='Europe/Moscow';
$TZs[]='Europe/Nicosia';
$TZs[]='Europe/Oslo';
$TZs[]='Europe/Paris';
$TZs[]='Europe/Prague';
$TZs[]='Europe/Riga';
$TZs[]='Europe/Rome';
$TZs[]='Europe/Samara';
$TZs[]='Europe/San_Marino';
$TZs[]='Europe/Sarajevo';
$TZs[]='Europe/Simferopol';
$TZs[]='Europe/Skopje';
$TZs[]='Europe/Sofia';
$TZs[]='Europe/Stockholm';
$TZs[]='Europe/Tallinn';
$TZs[]='Europe/Tirane';
$TZs[]='Europe/Tiraspol';
$TZs[]='Europe/Uzhgorod';
$TZs[]='Europe/Vaduz';
$TZs[]='Europe/Vatican';
$TZs[]='Europe/Vienna';
$TZs[]='Europe/Vilnius';
$TZs[]='Europe/Warsaw';
$TZs[]='Europe/Zagreb';
$TZs[]='Europe/Zaporozhye';
$TZs[]='Europe/Zurich';
$TZs[]='Indian/Antananarivo';
$TZs[]='Indian/Chagos';
$TZs[]='Indian/Christmas';
$TZs[]='Indian/Cocos';
$TZs[]='Indian/Comoro';
$TZs[]='Indian/Kerguelen';
$TZs[]='Indian/Mahe';
$TZs[]='Indian/Maldives';
$TZs[]='Indian/Mauritius';
$TZs[]='Indian/Mayotte';
$TZs[]='Indian/Reunion';
$TZs[]='Mexico/BajaNorte';
$TZs[]='Mexico/BajaSur';
$TZs[]='Mexico/General';
$TZs[]='Pacific/Apia';
$TZs[]='Pacific/Auckland';
$TZs[]='Pacific/Chatham';
$TZs[]='Pacific/Easter';
$TZs[]='Pacific/Efate';
$TZs[]='Pacific/Enderbury';
$TZs[]='Pacific/Fakaofo';
$TZs[]='Pacific/Fiji';
$TZs[]='Pacific/Funafuti';
$TZs[]='Pacific/Galapagos';
$TZs[]='Pacific/Gambier';
$TZs[]='Pacific/Guadalcanal';
$TZs[]='Pacific/Guam';
$TZs[]='Pacific/Honolulu';
$TZs[]='Pacific/Johnston';
$TZs[]='Pacific/Kiritimati';
$TZs[]='Pacific/Kosrae';
$TZs[]='Pacific/Kwajalein';
$TZs[]='Pacific/Majuro';
$TZs[]='Pacific/Marquesas';
$TZs[]='Pacific/Midway';
$TZs[]='Pacific/Nauru';
$TZs[]='Pacific/Niue';
$TZs[]='Pacific/Norfolk';
$TZs[]='Pacific/Noumea';
$TZs[]='Pacific/Pago_Pago';
$TZs[]='Pacific/Palau';
$TZs[]='Pacific/Pitcairn';
$TZs[]='Pacific/Ponape';
$TZs[]='Pacific/Port_Moresby';
$TZs[]='Pacific/Rarotonga';
$TZs[]='Pacific/Saipan';
$TZs[]='Pacific/Samoa';
$TZs[]='Pacific/Tahiti';
$TZs[]='Pacific/Tarawa';
$TZs[]='Pacific/Tongatapu';
$TZs[]='Pacific/Truk';
$TZs[]='Pacific/Wake';
$TZs[]='Pacific/Wallis';
$TZs[]='Pacific/Yap';
$TZs[]='US/Alaska';
$TZs[]='US/Aleutian';
$TZs[]='US/Arizona';
$TZs[]='US/Central';
$TZs[]='US/East-Indiana';
$TZs[]='US/Eastern';
$TZs[]='US/Hawaii';
$TZs[]='US/Indiana-Starke';
$TZs[]='US/Michigan';
$TZs[]='US/Mountain';
$TZs[]='US/Pacific';
$TZs[]='US/Pacific-New';
$TZs[]='US/Samoa';

?>
